# This file was auto-generated by Fern from our API Definition.

import typing
from ....types.system_message import SystemMessage
from ....types.user_message import UserMessage
from ....types.reasoning_message import ReasoningMessage
from ....types.tool_call_message import ToolCallMessage
from ....types.tool_return_message import ToolReturnMessage
from ....types.assistant_message import AssistantMessage

MessagesModifyResponse = typing.Union[
    SystemMessage, UserMessage, ReasoningMessage, ToolCallMessage, ToolReturnMessage, AssistantMessage
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_message_ids_item import AgentsSearchResponseAgentsItemMessageIdsItem

AgentsSearchResponseAgentsItemMessageIds = typing.Union[
    typing.List[str],
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemMessageIdsItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem = typing.Union[
    str, typing.Optional[str]
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tools_item_organization_id_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem,
)

TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationId = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemOrganizationIdItem]],
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Organization(UncheckedBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The human-friendly ID of the Org
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the organization.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The creation date of the organization.
    """

    privileged_tools: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the organization has access to privileged tools.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_termination_token_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
)

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem]
    ],
    typing.Optional[typing.Any],
]
